@@ -206,10 +206,13 @@ frdp_session_configure_event (GtkWidget *widget,
   FrdpSession *self = (FrdpSession*) user_data;
   FrdpSessionPrivate *priv = self->priv;
   GtkScrolledWindow *scrolled;
-  rdpSettings *settings = priv->freerdp_session->settings;
+  rdpSettings *settings;
   rdpGdi *gdi;
   double width, height;
 
+  if (priv->freerdp_session == NULL)
+    return;
+
   gdi = priv->freerdp_session->context->gdi;
   if (priv->surface == NULL) {
     create_cairo_surface (self);
@@ -219,6 +222,10 @@ frdp_session_configure_event (GtkWidget *widget,
   width = (double)gtk_widget_get_allocated_width (scrolled);
   height = (double)gtk_widget_get_allocated_height (scrolled);
 
+  if (priv->freerdp_session->settings == NULL)
+    return;
+  settings = priv->freerdp_session->settings;
+
   if (priv->scaling) {
     priv->scale_x = width / settings->DesktopWidth;
     priv->scale_y = height / settings->DesktopHeight;
@@ -246,6 +253,10 @@ frdp_session_draw (GtkWidget *widget,
 {
   FrdpSession *self = (FrdpSession*) user_data;
 
+  // Nothing to draw if disconnected
+  if (!self->priv->is_connected)
+    return FALSE;
+
   create_cairo_surface (self);
 
   if (self->priv->scaling) {
@@ -304,6 +315,13 @@ frdp_authenticate (freerdp  *freerdp_session,
 static gboolean
 frdp_pre_connect (freerdp *freerdp_session)
 {
+  rdpSettings *settings;
+
+  settings = freerdp_session->context->settings;
+
+  settings->RemoteFxCodec = TRUE;
+  settings->ColorDepth = 32;
+
   return TRUE;
 }
 
@@ -403,10 +421,6 @@ idle_close (gpointer user_data)
     g_clear_pointer (&self->priv->freerdp_session, freerdp_free);
   }
 
-  g_clear_pointer (&self->priv->hostname, g_free);
-  g_clear_pointer (&self->priv->username, g_free);
-  g_clear_pointer (&self->priv->password, g_free);
-
   g_signal_emit (self, signals[RDP_DISCONNECTED], 0);
   g_debug ("RDP client disconnected");
 
@@ -496,6 +510,7 @@ frdp_session_init_freerdp (FrdpSession *self)
   settings->DesktopResize = TRUE;
   settings->DynamicResolutionUpdate = TRUE;
   settings->SupportDisplayControl = TRUE;
+  settings->RedirectClipboard = FALSE;
 }
 
 static void
@@ -525,6 +540,7 @@ frdp_session_connect_thread (GTask        *task,
         case FREERDP_ERROR_CONNECT_TRANSPORT_FAILED:
         case ERRCONNECT_CONNECT_TRANSPORT_FAILED:
         case FREERDP_ERROR_TLS_CONNECT_FAILED:
+        case FREERDP_ERROR_DNS_NAME_NOT_FOUND:
             g_signal_emit (self,
                            signals[RDP_AUTH_FAILURE], 0,
                            freerdp_get_last_error_string (error_code));
